copy_code_giveaways

Function copy_code_giveaways 

async fn copy_code_giveaways(
    tx: &mut PgConnection,
    new_course_id: Uuid,
    old_course_id: Uuid,
) -> ModelResult<HashSet<Uuid>>
Copies the giveaways without their codes and returns the copies’ ids. Must run after the modules and the research consent questions are copied.