async fn copy_exam_exercises(
tx: &mut PgConnection,
namespace_id: Uuid,
parent_exam_id: Uuid,
) -> ModelResult<HashSet<Uuid>>Expand description
Copies the exercises of the copied exam pages and returns the copies’ ids.
async fn copy_exam_exercises(
tx: &mut PgConnection,
namespace_id: Uuid,
parent_exam_id: Uuid,
) -> ModelResult<HashSet<Uuid>>Copies the exercises of the copied exam pages and returns the copies’ ids.