async fn copy_page_audio_files(
tx: &mut PgConnection,
namespace_id: Uuid,
parent_id: Uuid,
) -> ModelResult<()>Expand description
The copies share the stored audio files with the source pages.
async fn copy_page_audio_files(
tx: &mut PgConnection,
namespace_id: Uuid,
parent_id: Uuid,
) -> ModelResult<()>The copies share the stored audio files with the source pages.