async fn set_chapter_front_pages(
tx: &mut PgConnection,
namespace_id: Uuid,
) -> ModelResult<()>Expand description
A chapter whose front page was not copied is left without one.
async fn set_chapter_front_pages(
tx: &mut PgConnection,
namespace_id: Uuid,
) -> ModelResult<()>A chapter whose front page was not copied is left without one.